function [disp_im] = fix_oversample(epc_im)
% function [disp_im] = fix_oversample(epc_im);
%
% Moves oversampled areas of EPIC image, based on CCU mode, so that image
%   is continuous, with the oversampled areas attached around the
%   periphery.
%
% Input:
%   epc_im  EPIC image structure
%
% optional:
%
% Output Structure disp_im, which is the same as epc_im, with the oversample
%   area shuffled, and disp_im.f_o added
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Operates on EPIC .epc files, written by EPICgse.
%
% 11/15/2009 Jeff Tobin, initial release
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin < 1, help(mfilename); error(mfilename); end

disp_im=epc_im;
disp_im.f_o=1;
disp_im.struc_type ='disp_im';

img=flipud(rot90(epc_im.image));
switch disp_im.CCU_mode,
  case {1 6}  % TRBL
    tb_image=[img(1017:1024,1:2048); img(1:1016,1:2048); ...
      img(1032:2048,1:2048); img(1025:1031,1:2048)];
    disp_im.image=[tb_image(1:1024,9:2048) tb_image(1:1024,1:8); ...
      tb_image(1025:2048,2041:2048) tb_image(1025:2048,1:2040)];

%    disp_im.oversampled_col_t=img(1:1024,1:8);
%    dism_im.oversampled_col_b=img(1025:2048,2041:2048);

% In Mode=1, on the top part of the image (1 <= y <= 1024),
%  the first 8 columns (1 <= x <= 8) are oversampled and
%  on the bottom part of the image (1025 <= y <= 2048), the
%  last 8 columns (2041 <= x <= 2048) are oversampled.
%   over_top_row=img(1:8,1:1024);
%   over_bot_row=img(2041:2048,1025:2048);

% In Mode=1, on the top part of the image (1 <= y <= 1024),
%  the last 8 rows (1017 <= y <= 1024) are oversampled and
%  on the bottom part of the image (1024 <= y <= 2047), the
%  first 7 rows (1025 <= y <= 1031) are oversampled
%   over_top_col=img(1:2048,1017:1024);
%   over_bot_col=img(1:2048,1025:1031);

% %% previous version
% 
% % %     if disp_im.across==2048 && disp_im.down==2048,
% %       r_image=flipud(rot90(image));
% %       s_image=zeros(size(r_image));
% %       s_image(1:9,:)=r_image(1016:1024,:);  % dark rows
% %       s_image(10:1024,:)=r_image(1:1015,:); % bulk image
% %       s_image(1025:2041,:)=r_image(1032:2048,:); % bulk image
% %       s_image(2042:2048,:)=r_image(1025:1031,:);  % dark rows
% % 
% %       disp_im.image=zeros(size(r_image));
% %       disp_im.image(1:1024,1:2040)=s_image(1:1024,9:2048);
% %       disp_im.image(1:1024,2041:2048)=s_image(1:1024,1:8);
% %       disp_im.image(1025:2048,1:8)=s_image(1025:2048,2041:2048);
% %       disp_im.image(1025:2048,9:2048)=s_image(1025:2048,1:2040);
% % %     else
% % %       disp_im.image=flipud(rot90(image));
% % %     end
  case 3
    disp_im.image=img;
%    disp_im.oversampled=disp_im.image(1:2048,2041:2048);
  case 4
     disp_im.image=img;
%     disp_im.oversampled=disp_im.image(1:2048,1:8);
  case {7 0 2 5}
%    image=rot90(epc_im.image);
    disp_im.image=flipud(img);
  otherwise
    warning('read_epc:unknownCcuMode','CCU is in an unknown mode: %d',...
      disp_im.CCU_mode);
    disp_im.image=img;
end

%disp_im=orderfields(disp_im);

return;
%